from django.template import Template, Context
from django.test import TestCase


class IncludeStaticTestCase(TestCase):
    """ Test the {% include_static %} template tag. """

    def setUp(self):
        pass

    def test_resulting_file_includes_static_file(self):
        # Arrange
        template = Template("abc {% load amptags %}{% include_static 'tests/static_file.txt' %} xyz")

        # Act
        rendered = template.render(Context({}))

        # Assert
        self.assertIn("The quick brown fox jumped over the lazy dog.", rendered)







import os

SECRET_KEY = 'TEST_SECRET_KEY'

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

ALLOWED_HOSTS = [
    'test.com',
]

INSTALLED_APPS = [
    'amptags',
    'tests',
]

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
    }
}

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [os.path.join(BASE_DIR, 'templates')],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]



from django import template
from django.contrib.staticfiles import finders

register = template.Library()


@register.simple_tag
def include_static(path: str):
    """ Inserts the contents of a static file verbatim into a Django template. """
    actual_path = finders.find(path)
    with open(actual_path, 'r', encoding='UTF-8') as f:
        content = f.read()
        return content

